@@ -8,10 +8,10 @@ import traceback
 def main():
 	# print("hello world")
 	parser = argparse.ArgumentParser(description="Creates a project directory with some default files and directories")
-	parser.add_argument("--createproject", help="Creates a project directory in current dir with given project name")
+	parser.add_argument("--create", help="Creates a project directory in current dir with given project name")
 	args = parser.parse_args()
-	if args.createproject:
-		project_name = args.createproject
+	if args.create:
+		project_name = args.create
 		print(f"Creating project {project_name}")
 		if project_name in os.listdir():
 			response = input(f"Project {project_name} already exists in current directory. Delete? (y/n) ")
@@ -20,5 +20,5 @@ def main():
 			else:
 				exit()
 		controller = CommandLineController()
-		controller.run(args.createproject)
+		controller.run(args.create)
 		print(f"Created project {project_name}")
\ No newline at end of file
